@@ -1135,23 +1135,107 @@ departments = {
     "Valle del Cauca":{
         "dane_code":"76",
         "municipalities":{
+            "Andalucía":{"dane_code":"76036"},
+            "Buga":{"dane_code":"76111"},
+            "Bugalagrande":{"dane_code":"76113"},
+            "Calima":{"dane_code":"76126"},
+            "El Cerrito":{"dane_code":"76248"},
+            "Ginebra":{"dane_code":"76306"},
+            "Guacarí":{"dane_code":"76318"},
+            "Restrepo":{"dane_code":"76606"},
+            "Riofrio":{"dane_code":"76616"},
+            "San Pedro":{"dane_code":"76670"},
+            "Trujillo":{"dane_code":"76828"},
+            "Tuluá":{"dane_code":"76834"},
+            "Yotoco":{"dane_code":"76890"},
+            "Alcala":{"dane_code":"76020"},
+            "Ansermanuevo":{"dane_code":"76041"},
+            "Argelia":{"dane_code":"76054"},
+            "Bolívar":{"dane_code":"76100"},
+            "Cartago":{"dane_code":"76147"},
+            "El Águila":{"dane_code":"76243"},
+            "El Cairo":{"dane_code":"76246"},
+            "El Dovio":{"dane_code":"76250"},
+            "La Unión":{"dane_code":"76400"},
+            "La Victoria":{"dane_code":"76403"},
+            "Obando":{"dane_code":"76497"},
+            "Roldanillo":{"dane_code":"76622"},
+            "Toro":{"dane_code":"76823"},
+            "Ulloa":{"dane_code":"76845"},
+            "Versalles":{"dane_code":"76863"},
+            "Zarzal":{"dane_code":"76895"},
+            "Buenaventura":{"dane_code":"76109"},
+            "Caicedonia":{"dane_code":"76122"},
+            "Sevilla":{"dane_code":"76736"},
+            "Candelaria":{"dane_code":"76130"},
+            "Dagua":{"dane_code":"76233"},
+            "Florida":{"dane_code":"76275"},
+            "Jamundí":{"dane_code":"76364"},
+            "La Cumbre":{"dane_code":"76377"},
+            "Palmira":{"dane_code":"76520"},
+            "Pradera":{"dane_code":"76563"},
+            "Vijes":{"dane_code":"76869"},
+            "Yumbo":{"dane_code":"76892"},
             "Santiago de Cali":{"dane_code":"76001"},
             "Cali":{"dane_code":"76001"},
             "Tuluá":{"dane_code":"76834"},
             "Florida":{"dane_code":"76275"},
             "Jamundí":{"dane_code":"76364"},
             "Buenaventura":{"dane_code":"76109"},
+            "palmira":{"dane_code":"76520"}
         }
     },
     "Valle":{
         "dane_code":"76",
         "municipalities":{
+            "Andalucía":{"dane_code":"76036"},
+            "Buga":{"dane_code":"76111"},
+            "Bugalagrande":{"dane_code":"76113"},
+            "Calima":{"dane_code":"76126"},
+            "El Cerrito":{"dane_code":"76248"},
+            "Ginebra":{"dane_code":"76306"},
+            "Guacarí":{"dane_code":"76318"},
+            "Restrepo":{"dane_code":"76606"},
+            "Riofrio":{"dane_code":"76616"},
+            "San Pedro":{"dane_code":"76670"},
+            "Trujillo":{"dane_code":"76828"},
+            "Tuluá":{"dane_code":"76834"},
+            "Yotoco":{"dane_code":"76890"},
+            "Alcala":{"dane_code":"76020"},
+            "Ansermanuevo":{"dane_code":"76041"},
+            "Argelia":{"dane_code":"76054"},
+            "Bolívar":{"dane_code":"76100"},
+            "Cartago":{"dane_code":"76147"},
+            "El Águila":{"dane_code":"76243"},
+            "El Cairo":{"dane_code":"76246"},
+            "El Dovio":{"dane_code":"76250"},
+            "La Unión":{"dane_code":"76400"},
+            "La Victoria":{"dane_code":"76403"},
+            "Obando":{"dane_code":"76497"},
+            "Roldanillo":{"dane_code":"76622"},
+            "Toro":{"dane_code":"76823"},
+            "Ulloa":{"dane_code":"76845"},
+            "Versalles":{"dane_code":"76863"},
+            "Zarzal":{"dane_code":"76895"},
+            "Buenaventura":{"dane_code":"76109"},
+            "Caicedonia":{"dane_code":"76122"},
+            "Sevilla":{"dane_code":"76736"},
+            "Candelaria":{"dane_code":"76130"},
+            "Dagua":{"dane_code":"76233"},
+            "Florida":{"dane_code":"76275"},
+            "Jamundí":{"dane_code":"76364"},
+            "La Cumbre":{"dane_code":"76377"},
+            "Palmira":{"dane_code":"76520"},
+            "Pradera":{"dane_code":"76563"},
+            "Vijes":{"dane_code":"76869"},
+            "Yumbo":{"dane_code":"76892"},
             "Santiago de Cali":{"dane_code":"76001"},
             "Cali":{"dane_code":"76001"},
             "Tuluá":{"dane_code":"76834"},
             "Florida":{"dane_code":"76275"},
             "Jamundí":{"dane_code":"76364"},
             "Buenaventura":{"dane_code":"76109"},
+            "palmira":{"dane_code":"76520"}
         }
     },
     "Vaupés":{
